@@ -16,7 +16,7 @@ EXCEL_MAXIMUM_ALLOWED_ROWS = 65536
 EXCEL_MAXIMUM_ALLOWED_COLUMN_WIDTH = 65535
 
 
-def __init__(self, data, output_name='excel_data', format='%Y%m%d%H%M%S', headers=None, force_csv=False, encoding='utf-8-sig', font='', sheet_name='Sheet 1', blanks_for_none=True, auto_adjust_width=True, vert=0x01, horz=0x01, row_merge=False):
+def __init__(self, data, output_name='excel_data', format='%Y%m%d%H%M%S', headers=None, force_csv=False, encoding='utf-8-sig', font='', sheet_name='Sheet 1', blanks_for_none=True, auto_adjust_width=True, min_cell_width=1000, vert=0x01, horz=0x01, row_merge=False):
     self.data = data
     self.output_name = output_name
     self.format = format
@@ -27,6 +27,7 @@ def __init__(self, data, output_name='excel_data', format='%Y%m%d%H%M%S', header
     self.sheet_name = sheet_name
     self.blanks_for_none = blanks_for_none
     self.auto_adjust_width = auto_adjust_width
+    self.min_cell_width = min_cell_width
     self.file_ext = None
     # VERT_TOP     = 0x00    顶端对齐
     # VERT_CENTER  = 0x01    居中对齐（垂直方向上）
@@ -37,21 +38,29 @@ def __init__(self, data, output_name='excel_data', format='%Y%m%d%H%M%S', header
     self.vert = vert
     self.horz = horz
 
+    if not isinstance(self.data, dict):
+        self.data = {self.sheet_name: self.data}
+
     # Make sure we've got the right type of data to work with
     # ``list index out of range`` if data is ``[]``
-    valid_data = False
-    if Support_ValuesQuerySet and isinstance(self.data, ValuesQuerySet):
-        self.data = list(self.data)
-    elif isinstance(self.data, QuerySet):
-        self.data = list(self.data.values())
-    if hasattr(self.data, '__getitem__'):
-        if isinstance(self.data[0], dict):
+    valid_data = True
+    for sheet_name, sheet_data in self.data.items():
+        if Support_ValuesQuerySet and isinstance(sheet_data, ValuesQuerySet):
+            sheet_data = list(sheet_data)
+        elif isinstance(sheet_data, QuerySet):
+            sheet_data = list(sheet_data.values())
+        if not hasattr(sheet_data, '__getitem__'):
+            valid_data = False
+            break
+        if isinstance(sheet_data[0], dict):
             if headers is None:
-                headers = list(self.data[0].keys())
-            self.data = [[row[col] for col in headers] for row in self.data]
-            self.data.insert(0, headers)
-        if hasattr(self.data[0], '__getitem__'):
-            valid_data = True
+                headers = list(sheet_data[0].keys())
+            sheet_data = [[row[col] for col in headers] for row in sheet_data]
+            sheet_data.insert(0, headers)
+        if not hasattr(sheet_data[0], '__getitem__'):
+            valid_data = False
+            break
+        self.data[sheet_name] = sheet_data
     assert valid_data is True, 'ExcelStorage requires a sequence of sequences'
 
     self.output = StringIO() if is_py2 else BytesIO()
